@@ -1,6 +1,10 @@
 
 ABtext <-
 function(textx){
+  
+  targetindex<-dev.cur() 
+  targetindex<-recordPlot() 
+  
   text<-NULL
   writeLines("------------------------------------------------------------------------")
   writeLines("Click the mouse where you want the text to begin.")
@@ -9,11 +13,12 @@ function(textx){
   text(locator(1),c(textx),cex=.9)
   u<-readline("accept text? (y/n) ")
   if (u=="n")
-  {replayPlot(ab)}
+
+  {replayPlot(targetindex)}
   
     
    
-    ab<-NULL
-  ab<<-recordPlot()
+    #ab<-NULL
+  #ab<<-recordPlot()
   
 }
