@@ -34,9 +34,9 @@ function(behavior,groupX,bandX,ABxlab,ABylab, ABmain){
   max=Uband+.3
   xmax<-length(p)+1
   
-  graphics.off()
+  #graphics.off()
   plot.new()
-  layout(rbind(1,2), heights=c(6,1))
+  layout(rbind(1,2), heights=c(4,1))
  plot(x,p,ylim=c(min,max),xlim=c(1,xmax),type="o",col="red",bty='L',main=ABmain,xlab=ABxlab,ylab=ABylab)
   
   abline(h=meanA,col="green")
@@ -53,7 +53,5 @@ function(behavior,groupX,bandX,ABxlab,ABylab, ABmain){
   print(puband)
   print(pmean)
   print(plband)
-  ab<-NULL
   
-  ab<<-recordPlot()
 }
